@@ -1,22 +1,20 @@
 /*=========================================================================
-
-  Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: RGBPointSet.cxx,v $
-  Language:  C++
-  Date:      $Date: 2009-04-06 00:05:54 $
-  Version:   $Revision: 1.15 $
-
-  Copyright (c) Insight Software Consortium. All rights reserved.
-  See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even 
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
-     PURPOSE.  See the above copyright notices for more information.
-
-=========================================================================*/
-#if defined(_MSC_VER)
-#pragma warning ( disable : 4786 )
-#endif
+ *
+ *  Copyright Insight Software Consortium
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *         http://www.apache.org/licenses/LICENSE-2.0.txt
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ *
+ *=========================================================================*/
 
 //  Software Guide : BeginLatex
 //
@@ -27,7 +25,7 @@
 //
 //  \index{itk::PointSet!RGBPixel}
 //
-//  Software Guide : EndLatex 
+//  Software Guide : EndLatex
 
 // Software Guide : BeginCodeSnippet
 #include "itkRGBPixel.h"
@@ -44,7 +42,7 @@ int main(int, char *[])
   //
   //  \index{itk::RGBPixel!Instantiation}
   //
-  //  Software Guide : EndLatex 
+  //  Software Guide : EndLatex
 
   // Software Guide : BeginCodeSnippet
   typedef itk::RGBPixel< float >    PixelType;
@@ -56,7 +54,7 @@ int main(int, char *[])
   //  The newly defined pixel type is now used to instantiate the PointSet
   //  type and subsequently create a point set object.
   //
-  //  Software Guide : EndLatex 
+  //  Software Guide : EndLatex
 
   // Software Guide : BeginCodeSnippet
   typedef itk::PointSet< PixelType, 3 > PointSetType;
@@ -66,14 +64,14 @@ int main(int, char *[])
 
   //  Software Guide : BeginLatex
   //
-  //  The following code is generating a sphere and assigning RGB values to
+  //  The following code generates a circle and assigns RGB values to
   //  the points. The components of the RGB values in this example are
   //  computed to represent the position of the points.
   //
   //  \index{itk::PointSet!SetPoint()}
   //  \index{itk::PointSet!SetPointData()}
   //
-  //  Software Guide : EndLatex 
+  //  Software Guide : EndLatex
 
   // Software Guide : BeginCodeSnippet
   PointSetType::PixelType   pixel;
@@ -84,14 +82,14 @@ int main(int, char *[])
   for(unsigned int i=0; i<360; i++)
     {
     const double angle = i * vnl_math::pi / 180.0;
-    point[0] = radius * vcl_sin( angle );
-    point[1] = radius * vcl_cos( angle );
+    point[0] = radius * std::sin( angle );
+    point[1] = radius * std::cos( angle );
     point[2] = 1.0;
     pixel.SetRed(    point[0] * 2.0 );
     pixel.SetGreen(  point[1] * 2.0 );
     pixel.SetBlue(   point[2] * 2.0 );
-    pointSet->SetPoint( pointId, point );   
-    pointSet->SetPointData( pointId, pixel );   
+    pointSet->SetPoint( pointId, point );
+    pointSet->SetPointData( pointId, pixel );
     pointId++;
     }
   // Software Guide : EndCodeSnippet
@@ -105,16 +103,16 @@ int main(int, char *[])
   //  \index{itk::PointSet!points iterator}
   //  \index{itk::PointSet!iterating points}
   //
-  //  Software Guide : EndLatex 
+  //  Software Guide : EndLatex
 
   // Software Guide : BeginCodeSnippet
   typedef  PointSetType::PointsContainer::ConstIterator     PointIterator;
   PointIterator pointIterator = pointSet->GetPoints()->Begin();
   PointIterator pointEnd      = pointSet->GetPoints()->End();
-  while( pointIterator != pointEnd ) 
+  while( pointIterator != pointEnd )
     {
     point = pointIterator.Value();
-    std::cout << point << std::endl;  
+    std::cout << point << std::endl;
     ++pointIterator;
     }
   // Software Guide : EndCodeSnippet
@@ -124,9 +122,9 @@ int main(int, char *[])
   //
   //  Note that here the \code{ConstIterator} was used instead of the
   //  \code{Iterator} since the pixel values are not expected to be modified.
-  //  ITK supports const-correctness at the API level. 
+  //  ITK supports const-correctness at the API level.
   //
-  //  Software Guide : EndLatex 
+  //  Software Guide : EndLatex
 
 
   //  Software Guide : BeginLatex
@@ -137,17 +135,17 @@ int main(int, char *[])
   //  \index{itk::PointSet!data iterator}
   //  \index{itk::PointSet!iterating point data}
   //
-  //  Software Guide : EndLatex 
+  //  Software Guide : EndLatex
 
 
   // Software Guide : BeginCodeSnippet
-  typedef  PointSetType::PointDataContainer::ConstIterator     PointDataIterator;
+  typedef  PointSetType::PointDataContainer::ConstIterator PointDataIterator;
   PointDataIterator pixelIterator = pointSet->GetPointData()->Begin();
   PointDataIterator pixelEnd      = pointSet->GetPointData()->End();
-  while( pixelIterator != pixelEnd ) 
+  while( pixelIterator != pixelEnd )
     {
     pixel = pixelIterator.Value();
-    std::cout << pixel << std::endl;  
+    std::cout << pixel << std::endl;
     ++pixelIterator;
     }
   // Software Guide : EndCodeSnippet
@@ -155,13 +153,13 @@ int main(int, char *[])
   //  Software Guide : BeginLatex
   //
   //  Again, please note the use of the  \code{ConstIterator} instead of the
-  //  \code{Iterator}. 
+  //  \code{Iterator}.
   //
   //  \index{ConstIterator}
   //  \index{const-correctness}
   //
-  //  Software Guide : EndLatex 
+  //  Software Guide : EndLatex
 
-  return 0;
+  return EXIT_SUCCESS;
 
 }
