@@ -1,29 +1,20 @@
 /*=========================================================================
-
-  Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: CurvesLevelSetImageFilter.cxx,v $
-  Language:  C++
-  Date:      $Date: 2005-08-31 14:58:36 $
-  Version:   $Revision: 1.9 $
-
-  Copyright (c) Insight Software Consortium. All rights reserved.
-  See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even 
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
-     PURPOSE.  See the above copyright notices for more information.
-
- =========================================================================*/
-#if defined(_MSC_VER)
-#pragma warning ( disable : 4786 )
-#endif
-
-#ifdef __BORLANDC__
-#define ITK_LEAN_AND_MEAN
-#endif
-
-
-
+ *
+ *  Copyright Insight Software Consortium
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *         http://www.apache.org/licenses/LICENSE-2.0.txt
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ *
+ *=========================================================================*/
 
 // Software Guide : BeginLatex
 //
@@ -49,7 +40,7 @@
 // between both examples.
 //
 // \begin{figure} \center
-// \includegraphics[width=\textwidth]{CurvessCollaborationDiagram1.eps}
+// \includegraphics[width=\textwidth]{CurvessCollaborationDiagram1}
 // \itkcaption[CurvesLevelSetImageFilter collaboration
 // diagram]{Collaboration diagram for the CurvesLevelSetImageFilter
 // applied to a segmentation task.}
@@ -74,20 +65,19 @@
 // in which the \emph{zero set} represents the initial contour. This level
 // set is also passed as input to the
 // CurvesLevelSetImageFilter.
-// 
+//
 // Finally, the level set generated by the
 // CurvesLevelSetImageFilter is passed to a
 // \doxygen{BinaryThresholdImageFilter} in order to produce a binary mask
 // representing the segmented object.
 //
 // Let's start by including the headers of the main filters involved in the
-// preprocessing. 
+// preprocessing.
 //
-// Software Guide : EndLatex 
+// Software Guide : EndLatex
 
 
 // Software Guide : BeginCodeSnippet
-#include "itkImage.h"
 #include "itkCurvesLevelSetImageFilter.h"
 // Software Guide : EndCodeSnippet
 
@@ -117,32 +107,32 @@ int main( int argc, char *argv[] )
 
 
   //  Software Guide : BeginLatex
-  //  
+  //
   //  We now define the image type using a particular pixel type and
   //  dimension. In this case the \code{float} type is used for the pixels
   //  due to the requirements of the smoothing filter.
   //
-  //  Software Guide : EndLatex 
+  //  Software Guide : EndLatex
 
   // Software Guide : BeginCodeSnippet
   typedef   float           InternalPixelType;
   const     unsigned int    Dimension = 2;
   typedef itk::Image< InternalPixelType, Dimension >  InternalImageType;
   // Software Guide : EndCodeSnippet
-                                     
+
 
   //  The following lines instantiate the thresholding filter that will
   //  process the final level set at the output of the
   //  CurvesLevelSetImageFilter.
   //
-  typedef unsigned char OutputPixelType;
+  typedef unsigned char                            OutputPixelType;
   typedef itk::Image< OutputPixelType, Dimension > OutputImageType;
-  typedef itk::BinaryThresholdImageFilter< 
-                        InternalImageType, 
-                        OutputImageType    >    ThresholdingFilterType;
-  
+  typedef itk::BinaryThresholdImageFilter<
+                        InternalImageType,
+                        OutputImageType    >       ThresholdingFilterType;
+
   ThresholdingFilterType::Pointer thresholder = ThresholdingFilterType::New();
-                        
+
   thresholder->SetLowerThreshold( -1000.0 );
   thresholder->SetUpperThreshold(     0.0 );
 
@@ -165,16 +155,16 @@ int main( int argc, char *argv[] )
   //  The RescaleIntensityImageFilter type is declared below. This filter will
   //  renormalize image before sending them to writers.
   //
-  typedef itk::RescaleIntensityImageFilter< 
-                               InternalImageType, 
+  typedef itk::RescaleIntensityImageFilter<
+                               InternalImageType,
                                OutputImageType >   CastFilterType;
 
 
   //  The \doxygen{CurvatureAnisotropicDiffusionImageFilter} type is
-  //  instantiated using the internal image type. 
+  //  instantiated using the internal image type.
   //
-  typedef   itk::CurvatureAnisotropicDiffusionImageFilter< 
-                               InternalImageType, 
+  typedef   itk::CurvatureAnisotropicDiffusionImageFilter<
+                               InternalImageType,
                                InternalImageType >  SmoothingFilterType;
 
   SmoothingFilterType::Pointer smoothing = SmoothingFilterType::New();
@@ -185,12 +175,12 @@ int main( int argc, char *argv[] )
   //  SigmoidImageFilter are instantiated using the internal image
   //  type.
   //
-  typedef   itk::GradientMagnitudeRecursiveGaussianImageFilter< 
-                               InternalImageType, 
+  typedef   itk::GradientMagnitudeRecursiveGaussianImageFilter<
+                               InternalImageType,
                                InternalImageType >  GradientFilterType;
 
-  typedef   itk::SigmoidImageFilter<                               
-                               InternalImageType, 
+  typedef   itk::SigmoidImageFilter<
+                               InternalImageType,
                                InternalImageType >  SigmoidFilterType;
 
   GradientFilterType::Pointer  gradientMagnitude = GradientFilterType::New();
@@ -214,8 +204,8 @@ int main( int argc, char *argv[] )
   //  will be used to generate the initial level set in the form of a distance
   //  map.
   //
-  typedef  itk::FastMarchingImageFilter< 
-                              InternalImageType, 
+  typedef  itk::FastMarchingImageFilter<
+                              InternalImageType,
                               InternalImageType >    FastMarchingFilterType;
 
 
@@ -223,25 +213,25 @@ int main( int argc, char *argv[] )
   //  method.
   //
   FastMarchingFilterType::Pointer  fastMarching = FastMarchingFilterType::New();
-  
+
   //  Software Guide : BeginLatex
-  //  
+  //
   //  In the following lines we instantiate the type of the
   //  CurvesLevelSetImageFilter and create an object of this
   //  type using the \code{New()} method.
   //
-  //  Software Guide : EndLatex 
+  //  Software Guide : EndLatex
 
   // Software Guide : BeginCodeSnippet
-  typedef  itk::CurvesLevelSetImageFilter< InternalImageType, 
+  typedef  itk::CurvesLevelSetImageFilter< InternalImageType,
                 InternalImageType >    CurvesFilterType;
-  CurvesFilterType::Pointer geodesicActiveContour = 
+  CurvesFilterType::Pointer geodesicActiveContour =
                                      CurvesFilterType::New();
   // Software Guide : EndCodeSnippet
 
-  
+
   //  Software Guide : BeginLatex
-  //  
+  //
   //  For the CurvesLevelSetImageFilter, scaling parameters
   //  are used to trade off between the propagation (inflation), the
   //  curvature (smoothing) and the advection terms. These parameters are set
@@ -257,7 +247,7 @@ int main( int argc, char *argv[] )
   //  \index{itk::Geodesic\-Active\-Contour\-LevelSet\-Image\-Filter!SetAdvectionScaling()}
   //  \index{itk::Segmentation\-Level\-Set\-Image\-Filter!SetAdvectionScaling()}
   //
-  //  Software Guide : EndLatex 
+  //  Software Guide : EndLatex
 
   const double propagationScaling = atof( argv[9] );
 
@@ -265,7 +255,7 @@ int main( int argc, char *argv[] )
   geodesicActiveContour->SetPropagationScaling( propagationScaling );
   geodesicActiveContour->SetCurvatureScaling( 1.0 );
   geodesicActiveContour->SetAdvectionScaling( 1.0 );
-  //  Software Guide : EndCodeSnippet 
+  //  Software Guide : EndCodeSnippet
 
   //  Once activiated the level set evolution will stop if the convergence
   //  criteria or if the maximum number of iterations is reached.  The
@@ -283,12 +273,12 @@ int main( int argc, char *argv[] )
 
 
   //  Software Guide : BeginLatex
-  //  
+  //
   //  The filters are now connected in a pipeline indicated in
   //  Figure~\ref{fig:CurvessCollaborationDiagram} using the
   //  following lines:
   //
-  //  Software Guide : EndLatex 
+  //  Software Guide : EndLatex
 
   // Software Guide : BeginCodeSnippet
   smoothing->SetInput( reader->GetOutput() );
@@ -308,7 +298,7 @@ int main( int argc, char *argv[] )
   //  images. However they may have to be adjusted depending on the amount of
   //  noise present in the input image. This filter has been discussed in
   //  section~\ref{sec:GradientAnisotropicDiffusionImageFilter}.
-  
+
   smoothing->SetTimeStep( 0.125 );
   smoothing->SetNumberOfIterations(  5 );
   smoothing->SetConductanceParameter( 9.0 );
@@ -318,7 +308,7 @@ int main( int argc, char *argv[] )
   //  equivalent of a convolution with a Gaussian kernel, followed by a
   //  derivative operator. The sigma of this Gaussian can be used to control
   //  the range of influence of the image edges. This filter has been discussed
-  //  in Section~\ref{sec:GradientMagnitudeRecursiveGaussianImageFilter}
+  //  in Section~\ref{sec:GradientMagnitudeRecursiveGaussianImageFilter}.
 
   const double sigma = atof( argv[6] );
   gradientMagnitude->SetSigma(  sigma  );
@@ -334,7 +324,7 @@ int main( int argc, char *argv[] )
 
   sigmoid->SetAlpha( alpha );
   sigmoid->SetBeta(  beta  );
-  
+
 
   //  The FastMarchingImageFilter requires the user to provide a seed
   //  point from which the level set will be generated. The user can actually
@@ -353,7 +343,7 @@ int main( int argc, char *argv[] )
   NodeContainer::Pointer seeds = NodeContainer::New();
 
   InternalImageType::IndexType  seedPosition;
-  
+
   seedPosition[0] = atoi( argv[3] );
   seedPosition[1] = atoi( argv[4] );
 
@@ -373,7 +363,7 @@ int main( int argc, char *argv[] )
   NodeType node;
 
   const double seedValue = - initialDistance;
-  
+
   node.SetValue( seedValue );
   node.SetIndex( seedPosition );
 
@@ -405,7 +395,7 @@ int main( int argc, char *argv[] )
   //  pedagogical/debugging purposes. These intermediate output are normaly not
   //  required. Only the output of the final thresholding filter should be
   //  relevant.  Observing intermediate output is helpful in the process of
-  //  fine tuning the parameters of filters in the pipeline. 
+  //  fine tuning the parameters of filters in the pipeline.
   //
   CastFilterType::Pointer caster1 = CastFilterType::New();
   CastFilterType::Pointer caster2 = CastFilterType::New();
@@ -452,17 +442,17 @@ int main( int argc, char *argv[] )
   //  only after the \code{Update()} methods of this filter has been called
   //  directly or indirectly.
   //
-  fastMarching->SetOutputSize( 
+  fastMarching->SetOutputSize(
            reader->GetOutput()->GetBufferedRegion().GetSize() );
 
-  
+
   //  Software Guide : BeginLatex
-  //  
+  //
   //  The invocation of the \code{Update()} method on the writer triggers the
   //  execution of the pipeline.  As usual, the call is placed in a
   //  \code{try/catch} block should any errors occur or exceptions be thrown.
   //
-  //  Software Guide : EndLatex 
+  //  Software Guide : EndLatex
 
   // Software Guide : BeginCodeSnippet
   try
@@ -476,7 +466,7 @@ int main( int argc, char *argv[] )
     }
   // Software Guide : EndCodeSnippet
 
-  // Print out some useful information 
+  // Print out some useful information
   std::cout << std::endl;
   std::cout << "Max. no. iterations: " << geodesicActiveContour->GetNumberOfIterations() << std::endl;
   std::cout << "Max. RMS error: " << geodesicActiveContour->GetMaximumRMSError() << std::endl;
@@ -524,8 +514,8 @@ int main( int argc, char *argv[] )
   //  \begin{center}
   //  \begin{tabular}{|l|c|c|c|c|c|c|c|c|}
   //  \hline
-  //  Structure    & Seed Index &  Distance   &   $\sigma$  &     
-  //  $\alpha$     &  $\beta$   & Propag. & Output Image \\  \hline 
+  //  Structure    & Seed Index &  Distance   &   $\sigma$  &
+  //  $\alpha$     &  $\beta$   & Propag. & Output Image \\  \hline
   //  Left Ventricle  & $(81,114)$ & 5.0 & 1.0 & -0.5 & 3.0  &  2.0 & First   \\  \hline
   //  Right Ventricle & $(99,114)$ & 5.0 & 1.0 & -0.5 & 3.0  &  2.0 & Second  \\  \hline
   //  White matter    & $(56, 92)$ & 5.0 & 1.0 & -0.3 & 2.0  & 10.0 & Third   \\  \hline
@@ -535,7 +525,7 @@ int main( int argc, char *argv[] )
   //  \itkcaption[Curves segmentation example parameters]{Parameters used
   //  for segmenting some brain structures shown in
   //  Figure~\ref{fig:CurvesImageFilterOutput2} using the filter
-  //  CurvesLevelSetImageFilter. 
+  //  CurvesLevelSetImageFilter.
   //  \label{tab:CurvesImageFilterOutput2}}
   //  \end{table}
   //
@@ -548,10 +538,10 @@ int main( int argc, char *argv[] )
   //  CurvesLevelSetImageFilter.
   //
   // \begin{figure} \center
-  // \includegraphics[height=0.40\textheight]{BrainProtonDensitySlice.eps}
-  // \includegraphics[height=0.40\textheight]{CurvesImageFilterOutput1.eps}
-  // \includegraphics[height=0.40\textheight]{CurvesImageFilterOutput2.eps}
-  // \includegraphics[height=0.40\textheight]{CurvesImageFilterOutput3.eps}
+  // \includegraphics[height=0.40\textheight]{BrainProtonDensitySlice}
+  // \includegraphics[height=0.40\textheight]{CurvesImageFilterOutput1}
+  // \includegraphics[height=0.40\textheight]{CurvesImageFilterOutput2}
+  // \includegraphics[height=0.40\textheight]{CurvesImageFilterOutput3}
   // \itkcaption[CurvesLevelSetImageFilter intermediate
   // output]{Images generated by the segmentation process based on the
   // CurvesLevelSetImageFilter. From left to right and top to
@@ -560,7 +550,7 @@ int main( int argc, char *argv[] )
   // image, sigmoid of the gradient magnitude. This last image, the sigmoid, is
   // used to compute the speed term for the front propagation.}
   // \label{fig:CurvesImageFilterOutput} \end{figure}
-  // 
+  //
   //  Segmentations of the main brain structures are presented in
   //  Figure~\ref{fig:CurvesImageFilterOutput2}. The results
   //  are quite similar to those obtained with the
@@ -576,10 +566,10 @@ int main( int argc, char *argv[] )
   //  contour evolution and adjusts these parameters accordingly.
   //
   // \begin{figure} \center
-  // \includegraphics[width=0.24\textwidth]{CurvesImageFilterOutput5.eps}
-  // \includegraphics[width=0.24\textwidth]{CurvesImageFilterOutput6.eps}
-  // \includegraphics[width=0.24\textwidth]{CurvesImageFilterOutput7.eps}
-  // \includegraphics[width=0.24\textwidth]{CurvesImageFilterOutput8.eps}
+  // \includegraphics[width=0.24\textwidth]{CurvesImageFilterOutput5}
+  // \includegraphics[width=0.24\textwidth]{CurvesImageFilterOutput6}
+  // \includegraphics[width=0.24\textwidth]{CurvesImageFilterOutput7}
+  // \includegraphics[width=0.24\textwidth]{CurvesImageFilterOutput8}
   // \itkcaption[CurvesImageFilter segmentations]{Images generated by the
   // segmentation process based on the CurvesImageFilter. From left to
   // right: segmentation of the left ventricle, segmentation of the right
@@ -588,11 +578,7 @@ int main( int argc, char *argv[] )
   // \label{fig:CurvesImageFilterOutput2}
   // \end{figure}
   //
-  //  Software Guide : EndLatex 
+  //  Software Guide : EndLatex
 
   return 0;
 }
-
-
-
-
