@@ -1,52 +1,47 @@
 /*=========================================================================
-
-  Program:   Insight Segmentation & Registration Toolkit
-  Module:    $RCSfile: GeodesicActiveContourImageFilter.cxx,v $
-  Language:  C++
-  Date:      $Date: 2005-11-20 13:27:54 $
-  Version:   $Revision: 1.44 $
-
-  Copyright (c) Insight Software Consortium. All rights reserved.
-  See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even 
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
-     PURPOSE.  See the above copyright notices for more information.
-
- =========================================================================*/
-#if defined(_MSC_VER)
-#pragma warning ( disable : 4786 )
-#endif
-
-#ifdef __BORLANDC__
-#define ITK_LEAN_AND_MEAN
-#endif
-
-
-
+ *
+ *  Copyright Insight Software Consortium
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *         http://www.apache.org/licenses/LICENSE-2.0.txt
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ *
+ *=========================================================================*/
 
 //  Software Guide : BeginCommandLineArgs
-//    INPUTS: {BrainProtonDensitySlice.png}
+//    INPUTS:  {BrainProtonDensitySlice.png}
 //    OUTPUTS: {GeodesicActiveContourImageFilterOutput5.png}
-//    81 114 5 1.0  -0.5  3.0   2
+//    ARGUMENTS:    81 114 5 1.0  -0.5  3.0   2
 //  Software Guide : EndCommandLineArgs
 //  Software Guide : BeginCommandLineArgs
-//    INPUTS: {BrainProtonDensitySlice.png}
+//    INPUTS:  {BrainProtonDensitySlice.png}
 //    OUTPUTS: {GeodesicActiveContourImageFilterOutput6.png}
-//    99 114 5 1.0  -0.5  3.0  2
+//    ARGUMENTS:    99 114 5 1.0  -0.5  3.0  2
 //  Software Guide : EndCommandLineArgs
-//  Software Guide : BeginCommandLineArgs
-//    INPUTS: {BrainProtonDensitySlice.png}
-//    OUTPUTS: {GeodesicActiveContourImageFilterOutput8.png}
-//    40 90 5 0.5  -0.3  2.0 10
-//  Software Guide : EndCommandLineArgs
-//  Software Guide : BeginCommandLineArgs
-//    INPUTS: {BrainProtonDensitySlice.png}
+ //  Software Guide : BeginCommandLineArgs
+//    INPUTS:  {BrainProtonDensitySlice.png}
 //    OUTPUTS: {GeodesicActiveContourImageFilterOutput7.png}
-//    OUTPUTS: [GeodesicActiveContourImageFilterOutput1.png]
-//    OUTPUTS: [GeodesicActiveContourImageFilterOutput2.png]
-//    OUTPUTS: [GeodesicActiveContourImageFilterOutput3.png]
-//    56 92 5 1.0  -0.3  2.0 10
+//    ARGUMENTS:    56 92 5.0 1.0 -0.3 2.0 10.0
+//  Software Guide : EndCommandLineArgs
+//  Software Guide : BeginCommandLineArgs
+//    INPUTS:  {BrainProtonDensitySlice.png}
+//    OUTPUTS: {GeodesicActiveContourImageFilterOutput8.png}
+//    ARGUMENTS:    40 90 5 0.5  -0.3  2.0 10
+//  Software Guide : EndCommandLineArgs
+//  Software Guide : BeginCommandLineArgs
+//    INPUTS:  {BrainProtonDensitySlice.png}
+//    OUTPUTS: {GeodesicActiveContourImageFilterOutput1.png}
+//    OUTPUTS: {GeodesicActiveContourImageFilterOutput2.png}
+//    OUTPUTS: {GeodesicActiveContourImageFilterOutput3.png}
+//    ARGUMENTS:    56 92 5 1.0  -0.3  2.0 10
 //  Software Guide : EndCommandLineArgs
 
 // Software Guide : BeginLatex
@@ -70,7 +65,7 @@
 // between both examples.
 //
 // \begin{figure} \center
-// \includegraphics[width=\textwidth]{GeodesicActiveContoursCollaborationDiagram1.eps}
+// \includegraphics[width=\textwidth]{GeodesicActiveContoursCollaborationDiagram1}
 // \itkcaption[GeodesicActiveContourLevelSetImageFilter collaboration
 // diagram]{Collaboration diagram for the GeodesicActiveContourLevelSetImageFilter
 // applied to a segmentation task.}
@@ -84,7 +79,7 @@
 // ShapeDetectionLevelSetImageFilter in
 // section~\ref{sec:ShapeDetectionLevelSetFilter}.
 //
-// The pipeline involves a first stage of smoothing using the
+// The pipeline involves a first stage of smoothing using the\newline
 // \doxygen{CurvatureAnisotropicDiffusionImageFilter}. The smoothed image is
 // passed as the input to the
 // \doxygen{GradientMagnitudeRecursiveGaussianImageFilter} and then to the
@@ -95,20 +90,19 @@
 // in which the \emph{zero set} represents the initial contour. This level
 // set is also passed as input to the
 // GeodesicActiveContourLevelSetImageFilter.
-// 
+//
 // Finally, the level set generated by the
 // GeodesicActiveContourLevelSetImageFilter is passed to a
 // \doxygen{BinaryThresholdImageFilter} in order to produce a binary mask
 // representing the segmented object.
 //
 // Let's start by including the headers of the main filters involved in the
-// preprocessing. 
+// preprocessing.
 //
-// Software Guide : EndLatex 
+// Software Guide : EndLatex
 
 
 // Software Guide : BeginCodeSnippet
-#include "itkImage.h"
 #include "itkGeodesicActiveContourLevelSetImageFilter.h"
 // Software Guide : EndCodeSnippet
 
@@ -138,32 +132,32 @@ int main( int argc, char *argv[] )
 
 
   //  Software Guide : BeginLatex
-  //  
+  //
   //  We now define the image type using a particular pixel type and
   //  dimension. In this case the \code{float} type is used for the pixels
   //  due to the requirements of the smoothing filter.
   //
-  //  Software Guide : EndLatex 
+  //  Software Guide : EndLatex
 
   // Software Guide : BeginCodeSnippet
   typedef   float           InternalPixelType;
   const     unsigned int    Dimension = 2;
   typedef itk::Image< InternalPixelType, Dimension >  InternalImageType;
   // Software Guide : EndCodeSnippet
-                                     
+
 
   //  The following lines instantiate the thresholding filter that will
   //  process the final level set at the output of the
   //  GeodesicActiveContourLevelSetImageFilter.
   //
-  typedef unsigned char OutputPixelType;
+  typedef unsigned char                            OutputPixelType;
   typedef itk::Image< OutputPixelType, Dimension > OutputImageType;
-  typedef itk::BinaryThresholdImageFilter< 
-                        InternalImageType, 
-                        OutputImageType    >    ThresholdingFilterType;
-  
+  typedef itk::BinaryThresholdImageFilter<
+                        InternalImageType,
+                        OutputImageType    >       ThresholdingFilterType;
+
   ThresholdingFilterType::Pointer thresholder = ThresholdingFilterType::New();
-                        
+
   thresholder->SetLowerThreshold( -1000.0 );
   thresholder->SetUpperThreshold(     0.0 );
 
@@ -186,16 +180,16 @@ int main( int argc, char *argv[] )
   //  The RescaleIntensityImageFilter type is declared below. This filter will
   //  renormalize image before sending them to writers.
   //
-  typedef itk::RescaleIntensityImageFilter< 
-                               InternalImageType, 
+  typedef itk::RescaleIntensityImageFilter<
+                               InternalImageType,
                                OutputImageType >   CastFilterType;
 
 
   //  The \doxygen{CurvatureAnisotropicDiffusionImageFilter} type is
-  //  instantiated using the internal image type. 
+  //  instantiated using the internal image type.
   //
-  typedef   itk::CurvatureAnisotropicDiffusionImageFilter< 
-                               InternalImageType, 
+  typedef   itk::CurvatureAnisotropicDiffusionImageFilter<
+                               InternalImageType,
                                InternalImageType >  SmoothingFilterType;
 
   SmoothingFilterType::Pointer smoothing = SmoothingFilterType::New();
@@ -206,12 +200,11 @@ int main( int argc, char *argv[] )
   //  SigmoidImageFilter are instantiated using the internal image
   //  type.
   //
-  typedef   itk::GradientMagnitudeRecursiveGaussianImageFilter< 
-                               InternalImageType, 
+  typedef   itk::GradientMagnitudeRecursiveGaussianImageFilter<
+                               InternalImageType,
                                InternalImageType >  GradientFilterType;
-
-  typedef   itk::SigmoidImageFilter<                               
-                               InternalImageType, 
+  typedef   itk::SigmoidImageFilter<
+                               InternalImageType,
                                InternalImageType >  SigmoidFilterType;
 
   GradientFilterType::Pointer  gradientMagnitude = GradientFilterType::New();
@@ -235,8 +228,8 @@ int main( int argc, char *argv[] )
   //  will be used to generate the initial level set in the form of a distance
   //  map.
   //
-  typedef  itk::FastMarchingImageFilter< 
-                              InternalImageType, 
+  typedef  itk::FastMarchingImageFilter<
+                              InternalImageType,
                               InternalImageType >    FastMarchingFilterType;
 
 
@@ -244,25 +237,25 @@ int main( int argc, char *argv[] )
   //  method.
   //
   FastMarchingFilterType::Pointer  fastMarching = FastMarchingFilterType::New();
-  
+
   //  Software Guide : BeginLatex
-  //  
+  //
   //  In the following lines we instantiate the type of the
   //  GeodesicActiveContourLevelSetImageFilter and create an object of this
   //  type using the \code{New()} method.
   //
-  //  Software Guide : EndLatex 
+  //  Software Guide : EndLatex
 
   // Software Guide : BeginCodeSnippet
-  typedef  itk::GeodesicActiveContourLevelSetImageFilter< InternalImageType, 
+  typedef  itk::GeodesicActiveContourLevelSetImageFilter< InternalImageType,
                 InternalImageType >    GeodesicActiveContourFilterType;
-  GeodesicActiveContourFilterType::Pointer geodesicActiveContour = 
+  GeodesicActiveContourFilterType::Pointer geodesicActiveContour =
                                      GeodesicActiveContourFilterType::New();
   // Software Guide : EndCodeSnippet
 
-  
+
   //  Software Guide : BeginLatex
-  //  
+  //
   //  For the GeodesicActiveContourLevelSetImageFilter, scaling parameters
   //  are used to trade off between the propagation (inflation), the
   //  curvature (smoothing) and the advection terms. These parameters are set
@@ -278,7 +271,7 @@ int main( int argc, char *argv[] )
   //  \index{itk::Geodesic\-Active\-Contour\-LevelSet\-Image\-Filter!SetAdvectionScaling()}
   //  \index{itk::Segmentation\-Level\-Set\-Image\-Filter!SetAdvectionScaling()}
   //
-  //  Software Guide : EndLatex 
+  //  Software Guide : EndLatex
 
   const double propagationScaling = atof( argv[9] );
 
@@ -286,7 +279,7 @@ int main( int argc, char *argv[] )
   geodesicActiveContour->SetPropagationScaling( propagationScaling );
   geodesicActiveContour->SetCurvatureScaling( 1.0 );
   geodesicActiveContour->SetAdvectionScaling( 1.0 );
-  //  Software Guide : EndCodeSnippet 
+  //  Software Guide : EndCodeSnippet
 
   //  Once activiated the level set evolution will stop if the convergence
   //  criteria or if the maximum number of iterations is reached.  The
@@ -304,12 +297,12 @@ int main( int argc, char *argv[] )
 
 
   //  Software Guide : BeginLatex
-  //  
+  //
   //  The filters are now connected in a pipeline indicated in
   //  Figure~\ref{fig:GeodesicActiveContoursCollaborationDiagram} using the
   //  following lines:
   //
-  //  Software Guide : EndLatex 
+  //  Software Guide : EndLatex
 
   // Software Guide : BeginCodeSnippet
   smoothing->SetInput( reader->GetOutput() );
@@ -329,7 +322,7 @@ int main( int argc, char *argv[] )
   //  images. However they may have to be adjusted depending on the amount of
   //  noise present in the input image. This filter has been discussed in
   //  section~\ref{sec:GradientAnisotropicDiffusionImageFilter}.
-  
+
   smoothing->SetTimeStep( 0.125 );
   smoothing->SetNumberOfIterations(  5 );
   smoothing->SetConductanceParameter( 9.0 );
@@ -339,7 +332,7 @@ int main( int argc, char *argv[] )
   //  equivalent of a convolution with a Gaussian kernel, followed by a
   //  derivative operator. The sigma of this Gaussian can be used to control
   //  the range of influence of the image edges. This filter has been discussed
-  //  in Section~\ref{sec:GradientMagnitudeRecursiveGaussianImageFilter}
+  //  in Section~\ref{sec:GradientMagnitudeRecursiveGaussianImageFilter}.
 
   const double sigma = atof( argv[6] );
   gradientMagnitude->SetSigma(  sigma  );
@@ -355,7 +348,7 @@ int main( int argc, char *argv[] )
 
   sigmoid->SetAlpha( alpha );
   sigmoid->SetBeta(  beta  );
-  
+
 
   //  The FastMarchingImageFilter requires the user to provide a seed
   //  point from which the level set will be generated. The user can actually
@@ -374,7 +367,7 @@ int main( int argc, char *argv[] )
   NodeContainer::Pointer seeds = NodeContainer::New();
 
   InternalImageType::IndexType  seedPosition;
-  
+
   seedPosition[0] = atoi( argv[3] );
   seedPosition[1] = atoi( argv[4] );
 
@@ -394,7 +387,7 @@ int main( int argc, char *argv[] )
   NodeType node;
 
   const double seedValue = - initialDistance;
-  
+
   node.SetValue( seedValue );
   node.SetIndex( seedPosition );
 
@@ -426,7 +419,7 @@ int main( int argc, char *argv[] )
   //  pedagogical/debugging purposes. These intermediate output are normaly not
   //  required. Only the output of the final thresholding filter should be
   //  relevant.  Observing intermediate output is helpful in the process of
-  //  fine tuning the parameters of filters in the pipeline. 
+  //  fine tuning the parameters of filters in the pipeline.
   //
   CastFilterType::Pointer caster1 = CastFilterType::New();
   CastFilterType::Pointer caster2 = CastFilterType::New();
@@ -473,17 +466,17 @@ int main( int argc, char *argv[] )
   //  only after the \code{Update()} methods of this filter has been called
   //  directly or indirectly.
   //
-  fastMarching->SetOutputSize( 
+  fastMarching->SetOutputSize(
            reader->GetOutput()->GetBufferedRegion().GetSize() );
 
-  
+
   //  Software Guide : BeginLatex
-  //  
+  //
   //  The invocation of the \code{Update()} method on the writer triggers the
   //  execution of the pipeline.  As usual, the call is placed in a
   //  \code{try/catch} block should any errors occur or exceptions be thrown.
   //
-  //  Software Guide : EndLatex 
+  //  Software Guide : EndLatex
 
   // Software Guide : BeginCodeSnippet
   try
@@ -497,7 +490,7 @@ int main( int argc, char *argv[] )
     }
   // Software Guide : EndCodeSnippet
 
-  // Print out some useful information 
+  // Print out some useful information
   std::cout << std::endl;
   std::cout << "Max. no. iterations: " << geodesicActiveContour->GetNumberOfIterations() << std::endl;
   std::cout << "Max. RMS error: " << geodesicActiveContour->GetMaximumRMSError() << std::endl;
@@ -545,8 +538,8 @@ int main( int argc, char *argv[] )
   //  \begin{center}
   //  \begin{tabular}{|l|c|c|c|c|c|c|c|c|}
   //  \hline
-  //  Structure    & Seed Index &  Distance   &   $\sigma$  &     
-  //  $\alpha$     &  $\beta$   & Propag. & Output Image \\  \hline 
+  //  Structure    & Seed Index &  Distance   &   $\sigma$  &
+  //  $\alpha$     &  $\beta$   & Propag. & Output Image \\  \hline
   //  Left Ventricle  & $(81,114)$ & 5.0 & 1.0 & -0.5 & 3.0  &  2.0 & First   \\  \hline
   //  Right Ventricle & $(99,114)$ & 5.0 & 1.0 & -0.5 & 3.0  &  2.0 & Second  \\  \hline
   //  White matter    & $(56, 92)$ & 5.0 & 1.0 & -0.3 & 2.0  & 10.0 & Third   \\  \hline
@@ -556,7 +549,7 @@ int main( int argc, char *argv[] )
   //  \itkcaption[GeodesicActiveContour segmentation example parameters]{Parameters used
   //  for segmenting some brain structures shown in
   //  Figure~\ref{fig:GeodesicActiveContourImageFilterOutput2} using the filter
-  //  GeodesicActiveContourLevelSetImageFilter. 
+  //  GeodesicActiveContourLevelSetImageFilter.
   //  \label{tab:GeodesicActiveContourImageFilterOutput2}}
   //  \end{table}
   //
@@ -569,10 +562,10 @@ int main( int argc, char *argv[] )
   //  GeodesicActiveContourLevelSetImageFilter.
   //
   // \begin{figure} \center
-  // \includegraphics[height=0.40\textheight]{BrainProtonDensitySlice.eps}
-  // \includegraphics[height=0.40\textheight]{GeodesicActiveContourImageFilterOutput1.eps}
-  // \includegraphics[height=0.40\textheight]{GeodesicActiveContourImageFilterOutput2.eps}
-  // \includegraphics[height=0.40\textheight]{GeodesicActiveContourImageFilterOutput3.eps}
+  // \includegraphics[height=0.40\textheight]{BrainProtonDensitySlice}
+  // \includegraphics[height=0.40\textheight]{GeodesicActiveContourImageFilterOutput1}
+  // \includegraphics[height=0.40\textheight]{GeodesicActiveContourImageFilterOutput2}
+  // \includegraphics[height=0.40\textheight]{GeodesicActiveContourImageFilterOutput3}
   // \itkcaption[GeodesicActiveContourLevelSetImageFilter intermediate
   // output]{Images generated by the segmentation process based on the
   // GeodesicActiveContourLevelSetImageFilter. From left to right and top to
@@ -581,7 +574,7 @@ int main( int argc, char *argv[] )
   // image, sigmoid of the gradient magnitude. This last image, the sigmoid, is
   // used to compute the speed term for the front propagation.}
   // \label{fig:GeodesicActiveContourImageFilterOutput} \end{figure}
-  // 
+  //
   //  Segmentations of the main brain structures are presented in
   //  Figure~\ref{fig:GeodesicActiveContourImageFilterOutput2}. The results
   //  are quite similar to those obtained with the
@@ -597,10 +590,10 @@ int main( int argc, char *argv[] )
   //  contour evolution and adjusts these parameters accordingly.
   //
   // \begin{figure} \center
-  // \includegraphics[width=0.24\textwidth]{GeodesicActiveContourImageFilterOutput5.eps}
-  // \includegraphics[width=0.24\textwidth]{GeodesicActiveContourImageFilterOutput6.eps}
-  // \includegraphics[width=0.24\textwidth]{GeodesicActiveContourImageFilterOutput7.eps}
-  // \includegraphics[width=0.24\textwidth]{GeodesicActiveContourImageFilterOutput8.eps}
+  // \includegraphics[width=0.24\textwidth]{GeodesicActiveContourImageFilterOutput5}
+  // \includegraphics[width=0.24\textwidth]{GeodesicActiveContourImageFilterOutput6}
+  // \includegraphics[width=0.24\textwidth]{GeodesicActiveContourImageFilterOutput7}
+  // \includegraphics[width=0.24\textwidth]{GeodesicActiveContourImageFilterOutput8}
   // \itkcaption[GeodesicActiveContourImageFilter segmentations]{Images generated by the
   // segmentation process based on the GeodesicActiveContourImageFilter. From left to
   // right: segmentation of the left ventricle, segmentation of the right
@@ -609,11 +602,7 @@ int main( int argc, char *argv[] )
   // \label{fig:GeodesicActiveContourImageFilterOutput2}
   // \end{figure}
   //
-  //  Software Guide : EndLatex 
+  //  Software Guide : EndLatex
 
   return 0;
 }
-
-
-
-
