@@ -449,12 +449,12 @@ public:
   {
     Vector< SpacePrecisionType, VImageDimension > cvector;
 
-    for ( unsigned int k = 0; k < VImageDimension; k++ )
+    for ( unsigned int k = 0; k < VImageDimension; ++k )
       {
       cvector[k] = point[k] - this->m_Origin[k];
       }
     cvector = m_PhysicalPointToIndex * cvector;
-    for ( unsigned int i = 0; i < VImageDimension; i++ )
+    for ( unsigned int i = 0; i < VImageDimension; ++i )
       {
       index[i] = static_cast< TIndexRep >( cvector[i] );
       }
@@ -474,10 +474,10 @@ public:
     const ContinuousIndex< TIndexRep, VImageDimension > & index,
     Point< TCoordRep, VImageDimension > & point) const
   {
-    for ( unsigned int r = 0; r < VImageDimension; r++ )
+    for ( unsigned int r = 0; r < VImageDimension; ++r )
       {
       TCoordRep sum = NumericTraits< TCoordRep >::ZeroValue();
-      for ( unsigned int c = 0; c < VImageDimension; c++ )
+      for ( unsigned int c = 0; c < VImageDimension; ++c )
         {
         sum += this->m_IndexToPhysicalPoint(r, c) * index[c];
         }
@@ -504,10 +504,10 @@ public:
      *   const IndexType & index,
      *   Point< TCoordRep, VImageDimension > & point) const
      * {
-     *   for ( unsigned int i = 0; i < VImageDimension; i++ )
+     *   for ( unsigned int i = 0; i < VImageDimension; ++i )
      *     {
      *     point[i] = this->m_Origin[i];
-     *     for ( unsigned int j = 0; j < VImageDimension; j++ )
+     *     for ( unsigned int j = 0; j < VImageDimension; ++j )
      *       {
      *       point[i] += m_IndexToPhysicalPoint[i][j] * index[j];
      *       }
@@ -538,11 +538,11 @@ public:
     //
     const DirectionType & direction = this->GetDirection();
 
-    for ( unsigned int i = 0; i < VImageDimension; i++ )
+    for ( unsigned int i = 0; i < VImageDimension; ++i )
       {
       typedef typename NumericTraits< TCoordRep >::AccumulateType CoordSumType;
       CoordSumType sum = NumericTraits< CoordSumType >::ZeroValue();
-      for ( unsigned int j = 0; j < VImageDimension; j++ )
+      for ( unsigned int j = 0; j < VImageDimension; ++j )
         {
         sum += direction[i][j] * inputGradient[j];
         }
@@ -569,11 +569,11 @@ public:
     //
     const DirectionType & inverseDirection = this->GetInverseDirection();
 
-    for ( unsigned int i = 0; i < VImageDimension; i++ )
+    for ( unsigned int i = 0; i < VImageDimension; ++i )
       {
       typedef typename NumericTraits< TCoordRep >::AccumulateType CoordSumType;
       CoordSumType sum = NumericTraits< CoordSumType >::ZeroValue();
-      for ( unsigned int j = 0; j < VImageDimension; j++ )
+      for ( unsigned int j = 0; j < VImageDimension; ++j )
         {
         sum += inverseDirection[i][j] * inputGradient[j];
         }
